
use "GHHS_PRQ_2025.dta", clear

*** Descripitive Statistics

* How many brief are written by teams (more than 1 attorney)
count if total_atty > 1
di 5430/6050

* How many briefs have women?
count if total_female_atty > 0
di 3192/6050

* How many briefs have multiple women?
count if total_female_atty > 1
di 1276/6050

* How many briefs have 5 or more women?
count if total_female_atty >=5
di 78/6050

* How many briefs exceed the 15,000 word limit
count if WC > 15000
di 1559/6050

* Over-dispersion of Strategic Citations
sum totMedCites

* How many briefs were written by female-majority teams?
count if propFem > 0.5
di 307/6050


*** Table 1: Descriptive Statistics
eststo sumstats: estpost summarize quantity_factor fkgl totMedCites simToMajOpin propFem attorney_factor logCoSignors logMaxFilExp medAligned logWC_LCOpin term simToLCOpin numBriefs oralArgQuesAdv, d quietly
estout sumstats, cells("min(fmt(2)) p25(fmt(2)) p50(fmt(2)) p75(fmt(2)) max(fmt(2))") label
* style(tex)
tab currentSG
tab petSide
tab unanBelow
tab amicusLC




*** Appendix A: Regression Results

** Table A.1: Crafting Briefs

* Quantity of Information
regress quantity_factor propFem attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
estimates store modQ 

* Grade Level
regress fkgl propFem attorney_factor currentSG logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term, robust cluster(caseLexCite) 
estimates store modR

* Strategic Citations
nbreg totMedCites propFem  attorney_factor currentSG logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term, robust cluster(caseLexCite) 
estimates store modS

estout modQ modR modS, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N bic) label varlabels(_cons Intercept) 


** Table A.2: Similarity to Opinions

* Model 1
glm simToMajOpin propFem quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)
estimates store modO1

* Model 2
glm simToMajOpin propFem simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)
estimates store modO2

estout modO1 modO2, cells((b(star fmt(3)) se(fmt(3) par))) starlevels(* 0.05) stats( N bic) label varlabels(_cons Intercept) 


*** Results Section Discusion

** Figure 2: Predicted Quantity of Information over range of Proportion Female
estimates restore modQ
margins, at(propFem=(0(0.1)1))
*marginsplot, xdimension(propFem) recast(line) plotopts(lwidth(medthick) lcolor(black)) recastci(rarea) ciopts(color(gs10) lcolor(gs10)) ytitle(Predicted Quantity of Information) xtitle(Proportion Female) title("Quantity of Information", color(black)) xsize(3) ysize(2.25) graphregion(lcolor(black) lwidth(thick)) graphregion(fcolor(white)) 

* Distribution of Quantity of Information
sum quantity_factor

** Figure 4: Predicted Grade Level over range of Proportion Female
estimates restore modR
margins, at(propFem=(0(0.1)1) )
*marginsplot, xdimension(propFem) recast(line) plotopts(lwidth(medthick) lcolor(black)) recastci(rarea) ciopts(color(gs10) lcolor(gs10)) ytitle(Predicted Grade Level) xtitle(Proportion Female) title("Grade Level", color(black)) xsize(3) ysize(2.25) graphregion(lcolor(black) lwidth(thick)) graphregion(fcolor(white)) 

* Distribution of Grade Level (n. 22)
sum fkgl

** Figure 6: Predicted Strategic Citations over range of Proportion Female
estimates restore modS
margins, at(propFem=(0(0.1)1) )
*marginsplot, xdimension(propFem) recast(line) plotopts(lwidth(medthick) lcolor(black)) recastci(rarea) ciopts(color(gs10) lcolor(gs10)) ytitle(Predicted Strategic Citations) xtitle(Proportion Female) title("Strategic Citations", color(black)) xsize(3) ysize(2.25) graphregion(lcolor(black) lwidth(thick)) graphregion(fcolor(white)) 

* Distribution of Strategic Citations
sum totMedCites, d

* Briefs with zero strategic citations
count if totMedCites == 0
di 2121/6050

* Note 23: Briefs with 5 or fewer strategic citations
count if totMedCites <= 5
di 4668/6050
* Note 23: Briefs with double-digit strategic citations
count if totMedCites >= 10
di 766/6050


*** Impact of Briefs 

** Indirect impact of legal team diversity on similarity to the majority opinion

* Predicted quantity of info from a maximally diverse team
estimates restore modQ
margins, at(propFem=0.5)
* Predicted quantity of info from a homogenous male team: 0.83
estimates restore modQ
margins, at(propFem=0)

* Predicted simiarlity to opinion for a diverse team with info predicted for that type of team
estimates restore modO1
margins, at(propFem=0.5 quantity_factor=0.89)
* Predicted simiarlity opinion for a homogenous male team with info predicted for that type of team
estimates restore modO1
margins, at(propFem=0 quantity_factor=0.83)

di (0.647-0.641)
di 2*(1 - normal(abs((0.647-0.641)/sqrt(0.0029^2+0.0024^2))))


*** Appendix B: Alternative Model Specification

** Table B.1: Robustness Checks

* Absolute distance from 0.5
regress quantity_factor  absDist attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
regress fkgl   absDist attorney_factor currentSG logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term, robust cluster(caseLexCite) 
nbreg totMedCites       absDist  attorney_factor currentSG logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term, robust cluster(caseLexCite) 
glm simToMajOpin absDist quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)

* Number of Women
regress quantity_factor total_female_atty attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
regress fkgl total_female_atty attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
nbreg totMedCites  total_female_atty attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
glm simToMajOpin total_female_atty quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)

* Binary: 1 or more women
regress quantity_factor any_female_atty attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
regress fkgl any_female_atty attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
nbreg totMedCites  any_female_atty attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
glm simToMajOpin any_female_atty quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)

* Gender Diversity Index
regress quantity_factor divIndex attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
regress fkgl divIndex attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
nbreg totMedCites  divIndex attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
glm simToMajOpin divIndex quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)

* Binary: More than 0.7 women 
regress quantity_factor  pct70 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
regress fkgl   pct70 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
nbreg totMedCites  pct70 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
glm simToMajOpin pct70 quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)

* Binary: More than 0.8 women 
regress quantity_factor  pct80 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
regress fkgl   pct80 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
nbreg totMedCites  pct80 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
glm simToMajOpin pct80 quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)

* Binary: More than 0.9 women 
regress quantity_factor  pct90 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
regress fkgl   pct90 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
nbreg totMedCites  pct90 attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
glm simToMajOpin pct90 quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)

* Excluding briefs by SG and states
regress quantity_factor  propFem attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term if currentSG==0 & numSt==0,  robust cluster(caseLexCite) 
regress fkgl   propFem  attorney_factor currentSG logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term if currentSG==0 & numSt==0, robust cluster(caseLexCite) 
nbreg totMedCites propFem  attorney_factor currentSG logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term if currentSG==0 & numSt==0, robust cluster(caseLexCite) 
glm simToMajOpin propFem quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term if currentSG==0 & numSt==0, link(logit) family(binomial) robust cluster(caseLexCite)

* Proportion Female excluding the SG
regress quantity_factor  pct_female_noSG attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term,  robust cluster(caseLexCite) 
regress fkgl   pct_female_noSG attorney_factor currentSG logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term, robust cluster(caseLexCite) 
nbreg totMedCites   pct_female_noSG  attorney_factor currentSG logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term, robust cluster(caseLexCite) 
glm simToMajOpin pct_female_noSG quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term, link(logit) family(binomial) robust cluster(caseLexCite)

* Control for Lagged Female participation added to model: % of briefs per year with any women as part of the team
regress quantity_factor propFem attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term lagged_fem_partic,  robust cluster(caseLexCite) 
regress fkgl propFem attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term lagged_fem_partic,  robust cluster(caseLexCite) 
nbreg totMedCites propFem attorney_factor currentSG  logCoSignors logMaxFilExp petSide medAligned logWC_LCOpin unanBelow amicusLC term lagged_fem_partic,  robust cluster(caseLexCite) 
glm simToMajOpin propFem quantity_factor fkgl totMedCites simToLCOpin numBriefs oralArgQuesAdv  attorney_factor  currentSG logCoSignors logMaxFilExp  petSide medAligned logWC_LCOpin unanBelow amicusLC term lagged_fem_partic, link(logit) family(binomial) robust cluster(caseLexCite)
